@@ -1,4 +1,4 @@
-from categorical_analysis import get_xr_occurrence
+from domino.categorical_analysis import get_xr_occurrence
 
 def aggregate_ds(ds,dim,agg_func,**agg_kwargs):
     return ds.map(agg_func,dim=dim,**agg_kwargs)
