@@ -251,7 +251,8 @@ class LaggedAnalyser(object):
         else:
                 comp=self._aggregate_from_ix(cat_ds,ix,dim,cat_func,cat_vals)
         comp.attrs=ds.attrs
-        return comp.assign_coords({'lag':[lag]})    
+        return comp.assign_coords({'lag':[lag]})
+
     
     #loops over all lags, calling _composite_from_ix, and assembles composites into a single dataset
     def _compute_aggregate_over_lags(self,da,dim,lag_vals,con_func,cat_func):
@@ -581,28 +582,19 @@ class LaggedAnalyser(object):
         return self.composite_sigs
     
     
-    def deseasonalise_variables(self,variable_list=None,dim='time',agg='dayofyear',smooth=1,coeffs=None):
+    def deseasonalise_variables(self,variable_list=None,dim='time'):
         if variable_list is None:
             variable_list=list(self.variables)
         for var in variable_list:
             da=self.variables[var]
             dsnlsr=Agg_Deseasonaliser()
-            if coeffs is None:
-                dsnlsr.fit_cycle(da,dim=dim,agg=agg)
-            else:
-                dsnslr.cycle_coeffs=coeffs[var]
-                
-            cycle=dsnlsr.evaluate_cycle(data=da[dim],smooth=smooth)
+            dsnlsr.fit_cycle(da)
+            cycle=dsnlsr.evaluate_cycle(da[dim])
             self.variables[var]=da.copy(data=da.data-cycle.data)
             dsnlsr.data=None #Prevents excess memory storage
             self.deseasonalisers_[var]=dsnlsr
         return
     
-    def get_seasonal_cycle_coeffs(self):
-        
-        coeffs=xr.Dataset({v:dsnlsr.cycle_coeffs for v,dsnlsr in self.deseasonalisers_.items()})
-        return coeffs
-
     #If deseasonalise_variables has been called, then this func can be used to compute the
     #seasonal mean state corresponding to a given composite. This mean state+ the composite
     # produced by self.compute_composites gives the full field composite pattern.
@@ -780,7 +772,6 @@ class IndexGenerator(object):
             drop=(~indices.isnull()).sum()==0
             drop=[k for k,d in drop.to_dict()['data_vars'].items() if d['data']]
             indices=indices.drop_vars(drop)
-            _=[(self.means.pop(x),self.stds.pop(x)) for x in drop]
             
         return indices
     
@@ -815,10 +806,7 @@ class IndexGenerator(object):
         func=self._rename_function
         return index.rename({v:func(v,sl) for v in index.data_vars})
     
-    def get_standardisation_params(self,as_dict=False):
-        if as_dict:
-            return self.means,self.stds
-        else:
-            params=[xr.Dataset(self.means),xr.Dataset(self.stds)]
-            return xr.concat(params,'param').assign_coords({'param':['mean','std']})
+    def get_standardisation_params(self):
+        
+        return self.means,self.stds
         
\ No newline at end of file
